@@ -6,5 +6,3 @@ from strange_case.nodes.file import FileNode
 from strange_case.nodes.asset import AssetNode
 from strange_case.nodes.page import PageNode
 from strange_case.nodes.jinja import JinjaNode
-from strange_case.nodes.image import ImageNode
-from strange_case.nodes.categories import CategoryDetail, CategoryFolderProcesser
